@@ -7,7 +7,7 @@ import logging
 # import seaborn as sn
 from toolkit_w.internal.api_requestor import APIRequestor
 from toolkit_w.internal.token_json import UserToken
-from toolkit_w.internal.vars_global import ProblemType, TargetMetric
+from toolkit_w.internal.vars_global import ProblemType, TargetMetric, FeatureType
 from toolkit_w.internal.vars_global import InterpretabilityLevel as Interpt
 from toolkit_w.resources.auth import authenticate
 import toolkit_w as my_toolkit
@@ -41,11 +41,14 @@ class MyWhatify:
             self.user_token = UserToken(my_toolkit.token)
             print("{} - Login successful".format(str(email)))
 
-    # def signup(self, user, password):
-    #     with allure.step('login with user: ' + user):
-    #         logging.info('login with user: ' + user)  # + ' and password: ' + password)
-    #         firefly.signup(username=user, password=password)
-    #         print("{} - Login successful".format(user))
+    def mark_ensemble_in_production(self, ensemble_id, mark_production=True):
+        with allure.step('setting ensemble_id: ' + str(ensemble_id) + ' as in production: ' + str(mark_production)):
+            logging.info('setting ensemble_id: ' + str(ensemble_id) + ' as in production: ' + str(mark_production))
+            if mark_production:
+                my_toolkit.Ensemble.set_ensemble_in_production(ensemble_id=ensemble_id)
+            else:
+                my_toolkit.Ensemble.remove_ensemble_in_production(ensemble_id=ensemble_id)
+
 
     def run_prediction(self, data_name, ensemble_id, data_file=None, wait=True, file_path=None, header=None, data_id=None):
         with allure.step('running prediction on data name: ' + data_name + ' with ensemble id: ' + str(ensemble_id) + ' and wait is: ' + str(wait)):
@@ -80,22 +83,20 @@ class MyWhatify:
                 print(e)
         return source_id
 
-    def preparing_data_set(self, source_id, data_set_name, sample_id=None, retype_columns=None, target='class', problem_type=ProblemType.CLASSIFICATION, wait=True):
-        if sample_id is None:
-            sample_id = ['car_id']
-        if retype_columns is None:
-            retype_columns = {'car_id': my_toolkit.vars_global.FeatureType.CATEGORICAL}
+    def preparing_data_set(self, source_id, data_set_name, sample_id=['car_id'],
+                           retype_columns={'car_id': FeatureType.CATEGORICAL}, target='class',
+                           problem_type=ProblemType.CLASSIFICATION, wait=True):
         with allure.step('Preparing Dataset name: ' + str(data_set_name) + ' source_id= ' + str(source_id) +
                      ' problem_type: ' + str(problem_type) + ' target: ' + str(target) + ' wait: ' + str(wait)):
             dataset_id = -1
-            task_type = eval(problem_type.value)
+            # task_type = eval(problem_type.value)
 
             try:
                 dataset_id = my_toolkit.resources.Datasource.prepare_data(
                     datasource_id=source_id,
                     dataset_name=data_set_name,
                     target=target,
-                    problem_type=task_type,
+                    problem_type=problem_type,
                     sample_id=sample_id,
                     retype_columns=retype_columns,
                     wait=wait, skip_if_exists=True)['id']
@@ -129,7 +130,7 @@ class MyWhatify:
                      ' interpt_level: ' + str(interpt_level) + ' training_time_in_minutes:' + str(training_time_in_minutes)):
             task_id = None
             ret_dict = None
-            target_metric_eval = eval(target_metric.value)
+            # target_metric_eval = eval(target_metric.value)
             # @markdown * Allocate training time
             # Training_time_in_minutes = training_time_in_minutes  # @param {type:'number'}
 
@@ -151,7 +152,7 @@ class MyWhatify:
                     task_name=data_name + " " + interpretability_level.name,
                     estimators=estimators,
                     pipeline=pipeline,
-                    target_metric=target_metric_eval,
+                    target_metric=target_metric,
                     dataset_id=dataset_id,
                     # splitting_strategy=firefly.enums.SplittingStrategy.STRATIFIED,
                     notes='created from Automation, run minutes: ' + str(training_time_in_minutes),
